@@ -15,7 +15,7 @@ use Pinto::ArchiveUnpacker;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.09999'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -166,6 +166,9 @@ sub __apply_workarounds {
     return $self->__fcgi_workaround(@provides)
         if $self->archive->basename =~ m/^ FCGI-\d /x;
 
+    return $self->__eumm_workaround(@provides)
+        if $self->archive->basename =~ m/ ExtUtils-MakeMaker /x;
+
     return @provides;
 }
 
@@ -199,6 +202,15 @@ sub __fcgi_workaround {
 
 #-----------------------------------------------------------------------------
 
+sub __eumm_workaround {
+  my ($self, @provides) = @_;
+
+  # See https://github.com/thaljef/Pinto/issues/204 
+  return grep { $_->{name} ne "version" } @provides;
+}
+
+#-----------------------------------------------------------------------------
+
 __PACKAGE__->meta->make_immutable;
 
 #-----------------------------------------------------------------------------
@@ -219,7 +231,7 @@ Pinto::PackageExtractor - Extract packages provided/required by a distribution a
 
 =head1 VERSION
 
-version 0.09999
+version 0.11
 
 =head1 AUTHOR
 
